{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { var root = inputs.input_filename.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_filename.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/iaintersect:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--a=",
                        "separate": false
                    },
                    "doc": "Annotation file, tsv",
                    "id": "#iaintersect.cwl/annotation_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--sam_ignorechr=",
                        "separate": false
                    },
                    "doc": "The chromosome to be ignored, string\n",
                    "id": "#iaintersect.cwl/ignore_chr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--in=",
                        "separate": false
                    },
                    "doc": "Input filename with MACS2 peak calling results, tsv",
                    "id": "#iaintersect.cwl/input_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--log=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.log');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Log filename\n",
                    "id": "#iaintersect.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--out=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.tsv');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Base output file name, tsv\n",
                    "id": "#iaintersect.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--promoter=",
                        "separate": false
                    },
                    "doc": "Promoter region around TSS, base pairs\n",
                    "id": "#iaintersect.cwl/promoter_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--upstream=",
                        "separate": false
                    },
                    "doc": "Upstream region before promoter, base pairs\n",
                    "id": "#iaintersect.cwl/upstream_bp"
                }
            ],
            "baseCommand": [
                "iaintersect"
            ],
            "doc": "Tool assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic)\n\n`default_output_filename` function returns output filename with sufix set as `ext` argument. Function is called when\neither `output_filename` or `log_filename` inputs are not provided.\n",
            "id": "#iaintersect.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#iaintersect-metadata.yaml",
                "http://schema.org/name": "iaintersect",
                "http://schema.org/about": "Based on BioWardrobe iaintersect (https://github.com/cincinnati-childrens-hospital/biowardrobe/tree/master/src/iaintersect) The software assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic).\n",
                "http://schema.org/url": "https://github.com/Barski-lab/iaintersect/blob/master/README.md",
                "http://schema.org/codeRepository": "https://github.com/Barski-lab/iaintersect",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/discussionUrl": [
                    "https://github.com/Barski-lab/iaintersect/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Barski Research Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Andrey Kartashov",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Michael Kotliar",
                                "http://schema.org/description": "Update to work with files instead of DB"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "iaintersect",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/iaintersect.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  iaintersect [options] --in=pathToFile --a=pathtoFile --out=pathToFile\n  --a                        \tTab-separated annotation file\n  --in                       \tInput filename with MACS2 peak calling results, xls\n  --log                      \tLog filename (default is ./logfile_def.log)\n  --out                      \tBase output file name\n  --promoter                 \tPromoter region around TSS in bp\n  --sam_ignorechr            \tThe chromosome to be ignored\n  --upstream                 \tUpstream region before promoter in bp\n",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.log_filename == \"\"){\n    return default_output_filename('_iaintersect.log');\n  } else {\n    return inputs.log_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename('_iaintersect.tsv');\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/result_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename) { return inputs.output_filename; } return inputs.unsorted_file.location.split('/').slice(-1)[0]; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-k, --key=POS1[,POS2]\nstart a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#linux-sort.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#linux-sort.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#linux-sort.cwl/unsorted_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#linux-sort.cwl/sorted_file",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    }
                }
            ],
            "stdout": "$(get_output_filename())",
            "baseCommand": [
                "sort"
            ],
            "doc": "Tool sorts data from `unsorted_file` by key\n\n`default_output_filename` function returns file name identical to `unsorted_file`, if `output_filename` is not provided.\n",
            "id": "#linux-sort.cwl",
            "http://schema.org/name": "linux-sort",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/linux-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { if (inputs.output_filename == \"\"){ var ext = \".gff\"; var root = inputs.islands_file.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.islands_file.basename+ext:root+ext; } else { return inputs.output_filename; } };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/rose:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "Control tab-delimited file (output from iaintersect.cwl or macs2-callpeak-biowardrobe-only.cwl tool)\n",
                    "id": "#makegff.cwl/islands_control_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Input tab-delimited file (output from iaintersect.cwl or macs2-callpeak-biowardrobe-only.cwl tool)\n",
                    "id": "#makegff.cwl/islands_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "valueFrom": "$(default_output_filename())"
                    },
                    "default": "",
                    "id": "#makegff.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(default_output_filename())"
                    },
                    "id": "#makegff.cwl/gff_file"
                }
            ],
            "baseCommand": [
                "makegff"
            ],
            "doc": "Tool produces GFF output from the file generated by iaintersect.cwl or macs2-callpeak-biowardrobe-only.cwl tool\nBoth islands_file and islands_control_file should be produced by the same tool\n",
            "id": "#makegff.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#makegff-metadata.yaml",
                "http://schema.org/name": "makegff",
                "http://schema.org/about": "makegff R script\n"
            },
            "http://schema.org/name": "makegff",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/makegff.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Tool produces GFF output from the file generated by iaintersect.cwl or macs2-callpeak-biowardrobe-only.cwl tool\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/rose:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-g"
                    },
                    "doc": "TSV genome annotation file",
                    "id": "#rose.cwl/annotation_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-r"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "Indexed bamfile to rank enhancer by",
                    "id": "#rose.cwl/bam_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-i"
                    },
                    "doc": "GFF or BED file of binding sites used to make enhancers",
                    "id": "#rose.cwl/binding_sites_file"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-s"
                    },
                    "doc": "Linking distance for stitching",
                    "id": "#rose.cwl/stitch_distance"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-t"
                    },
                    "doc": "Distance from TSS to exclude. 0 = no TSS exclusion",
                    "id": "#rose.cwl/tss_distance"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*AllEnhancers.table.txt"
                    },
                    "id": "#rose.cwl/all_enhancers_table"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Enhancers_withSuper.bed"
                    },
                    "id": "#rose.cwl/enhancers_with_super_bed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Gateway_Enhancers.bed"
                    },
                    "id": "#rose.cwl/gateway_enhancers_bed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Gateway_SuperEnhancers.bed"
                    },
                    "id": "#rose.cwl/gateway_super_enhancers_bed"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "gff"
                    },
                    "id": "#rose.cwl/gff_directory"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "mappedGFF"
                    },
                    "id": "#rose.cwl/mapped_gff_directory"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*Plot_points.png"
                    },
                    "id": "#rose.cwl/plot_points_pic"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*STITCHED_TSS_DISTAL_ENHANCER_REGION_MAP.txt"
                    },
                    "id": "#rose.cwl/stitched_enhancer_region_map"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*SuperEnhancers.table.txt"
                    },
                    "id": "#rose.cwl/super_enhancers_table"
                }
            ],
            "baseCommand": [
                "ROSE_main",
                "-o",
                "./"
            ],
            "doc": "Tool runs ROSE to get Super Enhancers regions\n-b and -c arguments are not supported\n",
            "id": "#rose.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#rose-metadata.yaml",
                "http://schema.org/name": "ROSE",
                "http://schema.org/about": "RANK ORDERING OF SUPER-ENHANCERS\n"
            },
            "http://schema.org/name": "rose",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/rose.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Updated version of the original ROSE\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "chipseq_sample": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-chipseq-se.cwl"
                ],
                "chipseq_control": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-chipseq-se.cwl"
                ],
                "genome_indices": [
                    "genome-indices.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "format": "http://edamontology.org/format_2572",
                    "label": "ChIP-Seq experiment",
                    "doc": "Coordinate sorted BAM file and BAI index file",
                    "sd:upstreamSource": "chipseq_sample/bambai_pair",
                    "sd:localLabel": true,
                    "id": "#main/alignment_file"
                },
                {
                    "type": "File",
                    "label": "Genome annotation",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "TSV genome annotation file",
                    "sd:upstreamSource": "genome_indices/annotation",
                    "id": "#main/annotation_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Chromosome length file",
                    "doc": "Chromosome length file",
                    "sd:upstreamSource": "genome_indices/chrom_length",
                    "id": "#main/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3468",
                    "label": "Control ChIP-Seq experiment",
                    "doc": "XLS file generated by MACS2 used as control",
                    "sd:upstreamSource": "chipseq_control/macs2_called_peaks",
                    "sd:localLabel": true,
                    "id": "#main/peak_control_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3468",
                    "label": "ChIP-Seq experiment",
                    "doc": "XLS file generated by MACS2",
                    "sd:upstreamSource": "chipseq_sample/macs2_called_peaks",
                    "sd:localLabel": true,
                    "id": "#main/peak_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1000,
                    "label": "Promoter distance, bp",
                    "doc": "Max distance from gene TSS (in both direction) overlapping which the peak will\nbe assigned to the promoter region. Default: 1000 bp\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/promoter_distance"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20000,
                    "label": "Maximum distance between two regions that will be stitched together",
                    "doc": "Maximum distance between two regions that will be stitched together.\nFor ROSE default is 12.5kb, in workflow default is 20000\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/stitching_distance"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2500,
                    "label": "Exclude regions contained within +/- this distance from TSS (skip TSS exclusion if 0)",
                    "doc": "Exclude regions contained within +/- this distance from TSS in order to account\nfor promoter biases (Default: 0; recommended if used: 2500). If this value is 0,\nwill not look for a gene file\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/tss_exclusion_zone_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20000,
                    "label": "Upstream distance, bp",
                    "doc": "Max distance from the promoter (only in upstream direction) overlapping which the\npeak will be assigned to the upstream region. Default: 20,000 bp\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/upstream_distance"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3603",
                    "label": "Ranked super-enhancers plot",
                    "doc": "Ranked super-enhancers plot",
                    "outputSource": "#main/rename_png/target_file",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Ranked super-enhancers plot"
                            }
                        }
                    ],
                    "id": "#main/ranked_super_enhancers_plot_png"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3004",
                    "label": "Super-enhancers",
                    "doc": "Super-enhancers bigBed file",
                    "outputSource": "#main/bed_to_bigbed/bigbed_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/super_enhancers_bigbed_file/igvbrowser",
                                "type": "bed",
                                "name": "#main/super_enhancers_bigbed_file/Super-enchancers",
                                "displayMode": "COLLAPSE",
                                "height": 40
                            }
                        }
                    ],
                    "id": "#main/super_enhancers_bigbed_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Super-enhancers report file (raw, from ROSE)",
                    "doc": "Super-enhancers report file (raw, from ROSE)",
                    "outputSource": "#main/run_rose/super_enhancers_table",
                    "id": "#main/super_enhancers_raw_txt"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "Super-enhancers report file with assigned genes",
                    "doc": "Super-enhancers report file with assigned genes",
                    "outputSource": "#main/add_island_names/output_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Super-enhancers",
                                "Title": "Super-enhancers Analysis Results"
                            }
                        }
                    ],
                    "id": "#main/super_enhancers_report_file"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": [
                                "#main/assign_genes/result_file",
                                "#main/sort_bed/sorted_file"
                            ],
                            "id": "#main/add_island_names/input_file"
                        },
                        {
                            "source": "#main/alignment_file",
                            "valueFrom": "$(self.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\"_default_s_enhcr.tsv\")",
                            "id": "#main/add_island_names/param"
                        }
                    ],
                    "out": [
                        "#main/add_island_names/output_file"
                    ],
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "requirements": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "biowardrobe2/scidap:v0.0.3"
                            }
                        ],
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 5
                                },
                                "doc": "TSV file to add extra columns too",
                                "id": "#main/add_island_names/e212f73f-67ab-4b8c-9324-cfa4401c496e/input_file"
                            },
                            {
                                "type": "string",
                                "inputBinding": {
                                    "position": 6
                                },
                                "doc": "Param to set output filename",
                                "id": "#main/add_island_names/e212f73f-67ab-4b8c-9324-cfa4401c496e/param"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/add_island_names/e212f73f-67ab-4b8c-9324-cfa4401c496e/output_file"
                            }
                        ],
                        "baseCommand": [
                            "bash",
                            "-c"
                        ],
                        "arguments": [
                            "echo -e \"refseq_id\\tgene_id\\ttxStart\\ttxEnd\\tstrand\\tchrom\\tstart\\tend\\tlength\\tregion\\tname\\tscore\" > `basename $2`; cat $0 | grep -v refseq_id | paste - $1 | cut -f 1-9,15,19,20 >> `basename $2`"
                        ],
                        "id": "#main/add_island_names/e212f73f-67ab-4b8c-9324-cfa4401c496e"
                    },
                    "id": "#main/add_island_names"
                },
                {
                    "run": "#iaintersect.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/assign_genes/annotation_filename"
                        },
                        {
                            "source": "#main/bed_to_macs/output_file",
                            "id": "#main/assign_genes/input_filename"
                        },
                        {
                            "source": "#main/promoter_distance",
                            "id": "#main/assign_genes/promoter_bp"
                        },
                        {
                            "source": "#main/upstream_distance",
                            "id": "#main/assign_genes/upstream_bp"
                        }
                    ],
                    "out": [
                        "#main/assign_genes/result_file"
                    ],
                    "id": "#main/assign_genes"
                },
                {
                    "in": [
                        {
                            "default": "bed4",
                            "id": "#main/bed_to_bigbed/bed_type"
                        },
                        {
                            "source": "#main/chrom_length_file",
                            "id": "#main/bed_to_bigbed/chrom_length_file"
                        },
                        {
                            "source": "#main/reduce_bed/output_file",
                            "id": "#main/bed_to_bigbed/input_bed"
                        },
                        {
                            "source": "#main/alignment_file",
                            "valueFrom": "$(self.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\"_default_s_enhcr.bb\")",
                            "id": "#main/bed_to_bigbed/output_filename"
                        }
                    ],
                    "out": [
                        "#main/bed_to_bigbed/bigbed_file"
                    ],
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "requirements": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "biowardrobe2/ucscuserapps:v358"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "string",
                                "inputBinding": {
                                    "position": 5,
                                    "prefix": "-type=",
                                    "separate": false
                                },
                                "doc": "Type of BED file in a form of bedN[+[P]]. By default bed3 to three required BED fields",
                                "id": "#main/bed_to_bigbed/292ac6d4-1e7d-4aff-b633-a0d745537adf/bed_type"
                            },
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 7
                                },
                                "doc": "Chromosome length files",
                                "id": "#main/bed_to_bigbed/292ac6d4-1e7d-4aff-b633-a0d745537adf/chrom_length_file"
                            },
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 6
                                },
                                "doc": "Input BED file",
                                "id": "#main/bed_to_bigbed/292ac6d4-1e7d-4aff-b633-a0d745537adf/input_bed"
                            },
                            {
                                "type": "string",
                                "inputBinding": {
                                    "position": 8
                                },
                                "doc": "Output filename",
                                "id": "#main/bed_to_bigbed/292ac6d4-1e7d-4aff-b633-a0d745537adf/output_filename"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/bed_to_bigbed/292ac6d4-1e7d-4aff-b633-a0d745537adf/bigbed_file"
                            }
                        ],
                        "baseCommand": [
                            "bedToBigBed"
                        ],
                        "doc": "Tool converts bed to bigBed",
                        "id": "#main/bed_to_bigbed/292ac6d4-1e7d-4aff-b633-a0d745537adf"
                    },
                    "id": "#main/bed_to_bigbed"
                },
                {
                    "in": [
                        {
                            "source": "#main/sort_bed/sorted_file",
                            "id": "#main/bed_to_macs/input_file"
                        }
                    ],
                    "out": [
                        "#main/bed_to_macs/output_file"
                    ],
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "requirements": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "biowardrobe2/scidap:v0.0.3"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 5
                                },
                                "doc": "Input file to be converted to MACS2 output format",
                                "id": "#main/bed_to_macs/11d704b8-63b3-4f59-8d1b-b5af0aa779c4/input_file"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/bed_to_macs/11d704b8-63b3-4f59-8d1b-b5af0aa779c4/output_file"
                            }
                        ],
                        "baseCommand": [
                            "bash",
                            "-c"
                        ],
                        "arguments": [
                            "cat $0 | grep -v \"#\" | awk 'BEGIN {print \"chr\\tstart\\tend\\tlength\\tabs_summit\\tpileup\\t-log10(pvalue)\\tfold_enrichment\\t-log10(qvalue)\\tname\"} {print $1\"\\t\"$2\"\\t\"$3\"\\t\"$3-$2+1\"\\t0\\t0\\t0\\t0\\t0\\t\"$4}' > `basename $0`"
                        ],
                        "doc": "Tool converts `input_file` to the format compatible with the input of iaintersect from `assign_genes` step",
                        "id": "#main/bed_to_macs/11d704b8-63b3-4f59-8d1b-b5af0aa779c4"
                    },
                    "id": "#main/bed_to_macs"
                },
                {
                    "run": "#makegff.cwl",
                    "in": [
                        {
                            "source": "#main/peak_control_file",
                            "id": "#main/make_gff/islands_control_file"
                        },
                        {
                            "source": "#main/peak_file",
                            "id": "#main/make_gff/islands_file"
                        }
                    ],
                    "out": [
                        "#main/make_gff/gff_file"
                    ],
                    "id": "#main/make_gff"
                },
                {
                    "in": [
                        {
                            "source": "#main/sort_bed/sorted_file",
                            "id": "#main/reduce_bed/input_file"
                        }
                    ],
                    "out": [
                        "#main/reduce_bed/output_file"
                    ],
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "requirements": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "biowardrobe2/scidap:v0.0.3"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 5
                                },
                                "doc": "Input BED6 file to be reduced to BED4",
                                "id": "#main/reduce_bed/5919b51f-ce4f-4463-b097-5145d2634413/input_file"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/reduce_bed/5919b51f-ce4f-4463-b097-5145d2634413/output_file"
                            }
                        ],
                        "baseCommand": [
                            "bash",
                            "-c"
                        ],
                        "arguments": [
                            "cat $0 | cut -f 1-4 > `basename $0`"
                        ],
                        "doc": "Tool converts BED6 to BED4 by reducing column numbers",
                        "id": "#main/reduce_bed/5919b51f-ce4f-4463-b097-5145d2634413"
                    },
                    "id": "#main/reduce_bed"
                },
                {
                    "in": [
                        {
                            "source": "#main/run_rose/plot_points_pic",
                            "id": "#main/rename_png/source_file"
                        },
                        {
                            "source": "#main/alignment_file",
                            "valueFrom": "$(self.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\"_default_s_enhcr.png\")",
                            "id": "#main/rename_png/target_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_png/target_file"
                    ],
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "requirements": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "biowardrobe2/scidap:v0.0.3"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 5
                                },
                                "doc": "source file to rename",
                                "id": "#main/rename_png/14286b49-22c3-4552-a690-391ba1afc980/source_file"
                            },
                            {
                                "type": "string",
                                "inputBinding": {
                                    "position": 6
                                },
                                "doc": "filename to rename to",
                                "id": "#main/rename_png/14286b49-22c3-4552-a690-391ba1afc980/target_filename"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "File",
                                "outputBinding": {
                                    "glob": "*"
                                },
                                "id": "#main/rename_png/14286b49-22c3-4552-a690-391ba1afc980/target_file"
                            }
                        ],
                        "baseCommand": [
                            "cp"
                        ],
                        "doc": "Tool renames (copy) `source_file` to `target_filename`",
                        "id": "#main/rename_png/14286b49-22c3-4552-a690-391ba1afc980"
                    },
                    "id": "#main/rename_png"
                },
                {
                    "run": "#rose.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/run_rose/annotation_file"
                        },
                        {
                            "source": "#main/alignment_file",
                            "id": "#main/run_rose/bam_file"
                        },
                        {
                            "source": "#main/make_gff/gff_file",
                            "id": "#main/run_rose/binding_sites_file"
                        },
                        {
                            "source": "#main/stitching_distance",
                            "id": "#main/run_rose/stitch_distance"
                        },
                        {
                            "source": "#main/tss_exclusion_zone_size",
                            "id": "#main/run_rose/tss_distance"
                        }
                    ],
                    "out": [
                        "#main/run_rose/plot_points_pic",
                        "#main/run_rose/gateway_super_enhancers_bed",
                        "#main/run_rose/super_enhancers_table"
                    ],
                    "id": "#main/run_rose"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n",
                                "3,3n"
                            ],
                            "id": "#main/sort_bed/key"
                        },
                        {
                            "source": "#main/run_rose/gateway_super_enhancers_bed",
                            "id": "#main/sort_bed/unsorted_file"
                        }
                    ],
                    "out": [
                        "#main/sort_bed/sorted_file"
                    ],
                    "id": "#main/sort_bed"
                }
            ],
            "label": "ROSE: rank ordering of super-enhancers",
            "doc": "Super-enhancers, consist of clusters of enhancers that are densely occupied by\nthe master regulators and Mediator. Super-enhancers differ from typical enhancers\nin size, transcription factor density and content, ability to activate transcription,\nand sensitivity to perturbation. Use to create stitched enhancers, and to separate\nsuper-enhancers from typical enhancers using sequencing data (.bam) given a file of\npreviously identified constituent enhancers (.gff)",
            "id": "#main",
            "http://schema.org/name": "ROSE: rank ordering of super-enhancers",
            "http://schema.org/alternateName": "ROSE: rank ordering of super-enhancers",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/super-enhancer.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
